# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from django.conf.urls import patterns, url

from api.v20.auth import (
    ApiAccountsAuthentication,
    ApiAccountRegistrationAuthentication,
    ApiEmailsAuthentication,
    ApiTokensAuthentication,
    ApiResource,
)
from api.v20.handlers import (
    AccountLoginHandler,
    AccountRegistrationHandler,
    AccountsHandler,
    EmailsHandler,
    PasswordResetTokenHandler,
    RequestsHandler,
    TokensHandler,
)


v2accounts = ApiResource(
    handler=AccountsHandler, authentication=ApiAccountsAuthentication())
v2emails = ApiResource(
    handler=EmailsHandler, authentication=ApiEmailsAuthentication())
v2login = ApiResource(handler=AccountLoginHandler)
v2password_reset = ApiResource(handler=PasswordResetTokenHandler)
v2registration = ApiResource(
    handler=AccountRegistrationHandler,
    authentication=ApiAccountRegistrationAuthentication())
v2requests = ApiResource(handler=RequestsHandler)
v2tokens = ApiResource(
    handler=TokensHandler, authentication=ApiTokensAuthentication())


urlpatterns = patterns(
    '',
    url(r'^accounts$', v2registration, name='api-registration'),
    url(r'^accounts/(?P<openid>\w+)$', v2accounts, name='api-account'),
    url(r'^emails/(?P<email>.+)$', v2emails, name='api-email'),
    url(r'^requests/validate$', v2requests, name='api-requests'),
    url(r'^tokens/oauth$', v2login, name='api-login'),
    url(r'^tokens/oauth/(?P<token>.+)$', v2tokens, name='api-token'),
    url(r'^tokens/password$', v2password_reset, name='api-password-reset'),
)
